@@ -4,16 +4,13 @@
 
 package Pod::Tree;
 
-require Exporter;
-
 use strict;
 use warnings;
 use IO::File;
 use Pod::Tree::Node;
 use Pod::Tree::Stream;
-use base qw(Exporter);
 
-$Pod::Tree::VERSION = '1.21';
+$Pod::Tree::VERSION = '1.22';
 
 sub new {
 	my $class = shift;
@@ -29,7 +26,7 @@ sub load_file {
 
 	Pod::Tree::Node->set_filename($file);
 
-	my $fh = new IO::File;
+	my $fh = IO::File->new;
 	$fh->open($file) or return '';
 	$tree->load_fh( $fh, %options );
 
@@ -44,7 +41,7 @@ sub load_fh {
 	$tree->_load_options(%options);
 	my $limit = $tree->{limit};
 
-	my $stream = new Pod::Tree::Stream $fh;
+	my $stream = Pod::Tree::Stream->new($fh);
 	my $paragraph;
 	my @paragraphs;
 	while ( $paragraph = $stream->get_paragraph ) {
