@@ -95,9 +95,9 @@ sub index {
 	my $top_page = $perl_dist->{top_page};
 	my $dest     = "$html_dir/$top_page";
 
-	my $fh = new IO::File ">$dest";
+	my $fh = IO::File->new(">$dest");
 	defined $fh or die "Pod::Tree::PerlDist::index: Can't open $dest: $!\n";
-	my $stream = new HTML::Stream $fh;
+	my $stream = HTML::Stream->new($fh);
 
 	my $options = $perl_dist->{options};
 	my $bgcolor = $options->{bgcolor};
@@ -152,9 +152,9 @@ sub translate {
 
 		my $entry  = $index->{$name};
 		my $source = $entry->{source};
-		open( FILE, $source )
+		open( my $FILE, '<', $source )
 			or die "Pod::Tree::PerlDist::translate: Can't open $source: $!\n";
-		my @file = <FILE>;
+		my @file = <$FILE>;
 
 		my $translate
 			= ( grep {/^=\w+/} @file )
@@ -171,7 +171,7 @@ sub translate_pod {
 	my $source  = $entry->{source};
 	my $dest    = $entry->{dest};
 	my $options = $perl_dist->{options};
-	my $html    = new Pod::Tree::HTML $source, $dest, %$options;
+	my $html    = Pod::Tree::HTML->new( $source, $dest, %$options );
 	$html->translate;
 }
 
@@ -181,13 +181,13 @@ sub translate_text {
 	my $source = $entry->{source};
 	my $dest   = $entry->{dest};
 
-	open( SOURCE, $source )
+	open( my $SOURCE, '<', $source )
 		or die "Pod::Tree::PerlDist::translate_text: Can't open $source: $!\n";
 
-	my $fh = new IO::File ">$dest";
+	my $fh = IO::File->new(">$dest");
 	defined $fh
 		or die "Pod::Tree::PerlDist::translate_text: Can't open $dest: $!\n";
-	my $stream = new HTML::Stream $fh;
+	my $stream = HTML::Stream->new($fh);
 
 	my $options = $perl_dist->{options};
 	my $bgcolor = $options->{bgcolor};
@@ -200,7 +200,7 @@ sub translate_text {
 	$stream->H1->t($title)->_H1;
 	$stream->PRE;
 
-	while ( my $line = <SOURCE> ) {
+	while ( my $line = <$SOURCE> ) {
 		$stream->t($line);
 	}
 
@@ -218,8 +218,8 @@ Pod::Tree::PerlDist - translate Perl distribution documentation to HTML
 
 =head1 SYNOPSIS
 
-  $perl_map  = new Pod::Tree::PerlMap;
-  $perl_dist = new Pod::Tree::PerlDist $perl_dir, $HTML_dir, $perl_map, %opts;
+  $perl_map  = Pod::Tree::PerlMap->new;
+  $perl_dist = Pod::Tree::PerlDist->new( $perl_dir, $HTML_dir, $perl_map, %opts );
 
   $perl_dist->scan;
   $perl_dist->index;
