@@ -7,7 +7,7 @@ sub mkdir {
 	my ( $translator, $dir ) = @_;
 
 	-d $dir
-		or CORE::mkdir $dir, 0755
+		or CORE::mkdir $dir, oct(755)
 		or die "Pod::Tree::PerlUtil::mkdir: Can't mkdir $dir: $!\n";
 }
 
@@ -38,7 +38,7 @@ sub report2 {
 sub get_name {
 	my ( $node, $source ) = @_;
 
-	my $tree = new Pod::Tree;
+	my $tree = Pod::Tree->new;
 	$tree->load_file($source);
 	my $children = $tree->get_root->get_children;
 	my @pod      = grep { is_pod $_ } @$children;
